@@ -1491,3 +1491,92 @@ def compute_alpha_signal_dynamical_ls_neutral(lo_df=None, core_tokens=['BTC', 'E
     merged_df['COMBO_STRAT'] = np.cumprod(1 + merged_df['STRAT_RETURN'].values)
     merged_df['DOLLAR_COMBO_STRAT'] = 10000. * np.cumprod(1 + merged_df['STRAT_RETURN'].values)
     return merged_df.copy()
+
+
+def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_tokens=None):
+    daily_rsi_lo_df = riskmetrics.filter_daily(rsilo_df.copy())
+    lo_close_colums = [f'close_{tok}' for tok in core_tokens + extra_tokens]
+    rsilo_close_colums = [f'close_{tok}' for tok in core_tokens]
+    lo_raw_sigs_colums = [f'SRAWLO{tok}' for tok in core_tokens + extra_tokens]
+    rsilo_raw_sigs_columns = [f'SRSILO{tok}' for tok in core_tokens]
+#    merged_sig_df = pd.merge(lo_df[lo_close_colums+lo_raw_sigs_colums].copy(), daily_rsi_lo_df[rsilo_close_colums+rsilo_raw_sigs_columns].copy(), right_index=True, left_index=True)
+    merged_sig_df = pd.merge(lo_df[lo_close_colums + lo_raw_sigs_colums + ['rebalance']].copy(),daily_rsi_lo_df[rsilo_raw_sigs_columns].copy(), right_index=True,left_index=True)
+
+    def mix_lo_rsilo(row, core_tokens=None, extra_tokens=None):
+        new_signals = {}
+        total_core_expo = 0
+        for token in core_tokens:
+            if row[f'SRAWLO{token}'] > 0. and row[f'SRSILO{token}'] > 0.:
+                new_signals[f'SMIX{token}'] = (row[f'SRAWLO{token}'] + row[f'SRSILO{token}']) / 2.
+                total_core_expo = total_core_expo + (row[f'SRAWLO{token}'] + row[f'SRSILO{token}']) / 2.
+            else:
+                new_signals[f'SMIX{token}'] = 0.
+            # new_signals[f'SMIX{token}'] = row[f'SRAWLO{token}']
+
+        for token in extra_tokens:
+            if total_core_expo > 0.:
+                new_signals[f'SMIX{token}'] = row[f'SRAWLO{token}']
+            else:
+                new_signals[f'SMIX{token}'] = 0
+
+        return new_signals
+
+    go_mixer = lambda x: mix_lo_rsilo(x, core_tokens=core_tokens, extra_tokens=extra_tokens)
+    final_lo_sig = merged_sig_df.apply(go_mixer, axis=1)
+    final_lo_sig_df = pd.DataFrame().from_records(final_lo_sig.values)
+    final_lo_sig_df.index = final_lo_sig.index
+    merged_sig_df = pd.merge(merged_sig_df.copy(), final_lo_sig_df.copy(), left_index=True, right_index=True)
+
+
+
+    all_tokens = core_tokens + extra_tokens
+    n_max = int(len(all_tokens) / 2.) + 1
+
+    def get_expo(row, n_max=None, all_tokens=None):
+        signals = [f'SMIX{tok}' for tok in core_tokens + extra_tokens]
+        total_sig = 0
+        for sig in signals:
+            total_sig = total_sig + row[sig]
+        expo = 0.
+        if total_sig > n_max:
+            expo = 1. / total_sig
+        elif total_sig > 0.:
+            expo = 1. / n_max
+        else:
+            expo = 0.
+        return expo
+
+    go_get_expo = lambda x: get_expo(x, n_max=n_max, all_tokens=all_tokens)
+
+    merged_sig_df['expo'] = merged_sig_df.apply(go_get_expo, axis=1)
+
+    for tok in all_tokens:
+        merged_sig_df[f'return_{tok}'] = merged_sig_df[f'close_{tok}'].pct_change()
+        merged_sig_df[f'return_{tok}'] = merged_sig_df[f'return_{tok}'].fillna(0.)
+        merged_sig_df[f'return_{tok}'] = merged_sig_df[f'return_{tok}'].replace([np.inf], 0)
+
+    new_merged_sig_df = merged_sig_df.dropna()
+
+    def compute_strat_perf(row, all_tokens=None):
+        global_return = 0.
+        expo = row['expo']
+        for tok in all_tokens:
+            global_return = global_return + row[f'return_{tok}'] * row[f'SMIX{tok}'] * expo
+        return global_return
+
+    go_comp = lambda x: compute_strat_perf(x, all_tokens=all_tokens)
+    new_merged_sig_df['strat_return'] = new_merged_sig_df.apply(go_comp, axis=1)
+
+    new_merged_sig_df['strat'] = np.cumprod(1. + new_merged_sig_df['strat_return'].values)
+
+    plot_html = True
+    if plot_html:
+        dollar_df = new_merged_sig_df[['strat']].copy()
+        new_names = {'strat': 'Absolute Return Weekly LO Strategy'}
+        dollar_df = dollar_df.rename(columns=new_names)
+        fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=dollar_df,
+                                                                         logy=True, split=False,
+                                                                         put_on_same_scale=False,
+                                                                         title=f'strategy performance')
+        fig.show()
+    return new_merged_sig_df
\ No newline at end of file
